# This program can be used to reproduce the empirical analyses appearing in Section 5 and Appendix F (Supplement p. 53) of 
# Escanciano & Goh (2018),  ``Quantile-Regression Inference with Adaptive Control of Size''

# The dataset used is contained in `Penn46.ascii.txt', which should be placed in the same working 
# directory used by this program.  This dataset can be downloaded from
# http://www.econ.uiuc.edu/~roger/research/inference/Penn46.ascii.

# Users will at minimum need to specify:
#   either the actual number m of random quantiles used, or the leading constant used to specify 
#     the recommended setting of m; see eq. (14) in the main text ('km'; the paper used km=5)

a1 <- .20 # left endpoint of grid of quantiles considered
a2 <- .80 # right endpoint of grid of quantiles considered
alphagrid <- c(seq(a1,a2,length.out=300)) # entire grid of quantiles considered


library(quantreg)
library(mvtnorm)
library(ks)
library(MASS)
library(latex2exp)

raw.data <- read.table("Penn46.ascii.txt", header=TRUE)

# Assign variable names to columns in raw data matrix

yy <- raw.data[,2] # duration of unemployment, weeks
x1 <- raw.data[,3] # treatment indicator
x2 <- raw.data[,4] # female indicator
x3 <- raw.data[,5] # black indicator
x4 <- raw.data[,6] # Hispanic indicator
x5 <- raw.data[,7] # number of dependents, with 2 indicating >=2 dependents
x6 <- raw.data[,8] # indicator for whether the claimant expected to be recalled to a previous job
x7 <- raw.data[,9] # indicator for respondent being ``young'', i.e., younger than 35
x8 <- raw.data[,10] # indicator for respondent being ``old'', i.e., older than 54
x9 <- raw.data[,11] # variable denoting the five quarters of entry to the experiment
x91 <- ifelse(x9==1,1,0)
x92 <- ifelse(x9==2,1,0)
x93 <- ifelse(x9==3,1,0)
x94 <- ifelse(x9==4,1,0)
x95 <- ifelse(x9==5,1,0)
x10 <- raw.data[,12] # indicator for whether claimant was employed in the durable goods industry
x11 <- raw.data[,13] # indicator for whether the claimant was registered in one of the low-unemployment, 
                     # short-unemployment-duration districts:  Coatesville, Reading or Lancaster

# Define interaction variables
x1x2 <- x1*x2 # treatment with female
x1x3 <- x1*x3 # treatment with black
x1x4 <- x1*x4 # treatment with Hispanic
x1x5 <- x1*x5 # treatment with no. of dependents
x1x6 <- x1*x6 # treatment with indicator for whether claimant expects to be recalled
x1x7 <- x1*x7 # treatment with young
x1x8 <- x1*x8 # treatment with old
x1x91 <- x1*x91 # treatment with quarter 1 indicator
x1x92 <- x1*x92 # treatment with quarter 2 indicator
x1x93 <- x1*x93 # treatment with quarter 3 indicator
x1x94 <- x1*x94 # treatment with quarter 4 indicator
x1x95 <- x1*x95 # treatment with quarter 5 indicator
x1x10 <- x1*x10 # treatment with employment in durable goods sector
x1x11 <- x1*x11 # treatment with LUSD district

x1x2x7 <- x1*x2*x7 # treatment with female with young
x1x2x8 <- x1*x2*x8 # treatment with female with old

x2x3 <- x2*x3 # female times black
x2x4 <- x2*x4 # female times Hispanic


x2x5 <- x2*x5 # female times number of dependents
x1x2x5 <- x1*x2*x5 # treatment with female times number of dependents

y <- log(yy)
n <- length(y)



aa1 <- 0
aa2 <- 1

km <- 5


# the eg.proc procedure returns the \hat{G} matrix along with the suggested data-driven bandwidth 
# appearing in our paper
eg.proc <- function(R,X,y,qtile,a1,a2,m.fixed=TRUE,m,km=1) { 
  # X should not contain an intercept
  betahat <- rq(y~X, tau=qtile)
  info <- t(betahat$coefficients)
  n <- length(y)
  Xplus <- cbind(rep(1,n),X)
  d <- dim(Xplus)[2]
  qn <- n^(-1)*crossprod(Xplus,Xplus)
  if (m.fixed==FALSE) {
    m <- floor(km*(n/(log(n)^(11/5)))^(5/4))
  }
  unifs <- runif(m, min=a1,max=a2)
  unifs <- sort(unifs)
  betahat.grid <- rq(y~X, tau=unifs)
  info.grid <-t(betahat.grid$coefficients)
  
  prelim <- lm(y~X)
  info.resid <- prelim$residuals
  info.resid <- sort(info.resid, decreasing=FALSE, index.return=TRUE)
  bottom <- floor(n*a1)
  top <- floor(n*a2)
  if (top-bottom <=d) {
    bottom <- floor(n*(qtile-d/(2*n)))
    top <- floor(n*(qtile+d/(2*n)))
  }
  y.adj <- y[c(info.resid$ix[c(-(1:bottom),-(top+1:n))])]
  X.adj <- X[c(info.resid$ix[c(-(1:bottom),-(top+1:n))]),]
  n.adj <- length(y.adj)
  
  bmid <- rq(y.adj~X.adj, tau=qtile)$coefficients
  X.adj <- cbind(rep(1,n.adj),X.adj)
  xbhat <- X.adj %*% bmid
  
  xbhat.mat <- X.adj %*% t(info.grid)
  
  fhat.vec <- numeric(n.adj)
  f2hat.vec <- numeric(n.adj)
  hpre <- m^(-1/5)
  hpre2 <- m^(-1/9)
  for (ii in 1:n.adj) { 
    fhat.vec[ii] <- kdde(x=xbhat.mat[ii,], eval.points=xbhat[ii],deriv.order=0, h=hpre)$estimate
    f2hat.vec[ii] <- kdde(x=xbhat.mat[ii,], eval.points=xbhat[ii],deriv.order=2,h=hpre2)$estimate
  }
  
  fhat <- diag(fhat.vec)
  f2hat <- diag(f2hat.vec)
  t1hat <- (n.adj^(-1))*t(X.adj) %*% f2hat %*% X.adj
  sqrtfhat <- diag(sqrt(fhat.vec))
  t2hat <- (n.adj^(-1))*t(X.adj) %*% sqrtfhat %*% X.adj
  ghat <- (n.adj^(-1))*t(X.adj) %*% fhat %*% X.adj
  u1hat <- ginv(R %*% ginv(ghat) %*% qn %*% ginv(ghat) %*% t(R)) %*% (R %*% (ginv(ghat) %*% t1hat %*% ginv(ghat) %*% qn %*% ginv(ghat)+ginv(ghat) %*% qn %*% ginv(ghat) %*% t1hat %*% ginv(ghat))%*% t(R))%*% ginv(R %*% ginv(ghat) %*% qn %*% ginv(ghat) %*% t(R))
  lambda1hat <- info %*% t(R) %*% u1hat %*% R %*% t(info)
  u2hat <- ginv(R %*% ginv(ghat) %*% qn %*% ginv(ghat) %*% t(R)) %*% (R %*% (ginv(ghat) %*% t2hat %*% ginv(ghat) %*% qn %*% ginv(ghat)+ginv(ghat) %*% qn %*% ginv(ghat) %*% t2hat %*% ginv(ghat)) %*% t(R)) %*% ginv(R %*% ginv(ghat) %*% qn %*% ginv(ghat) %*% t(R))
  lambda2hat <- info %*% t(R) %*% u2hat %*% R %*% t(info)
  
  const.bw <- (lambda2hat^2/(lambda1hat^2))^(1/5)
  heg <- const.bw*(log(m)/m)^(1/5) # rate-optimal bandwidth
  heg <- c(heg)
  kern <- .75*(matrix(rep(1,n*m),nrow=n)-(heg^(-1)*(Xplus %*% t(info.grid)-Xplus %*% kronecker(t(info),matrix(rep(1,m),nrow=1))))^2)*(abs(heg^(-1)*(Xplus %*% t(info.grid)-Xplus %*% kronecker(t(info),matrix(rep(1,m),nrow=1))))<=1)
  
  blah <- (a2-a1)*heg^(-1)*kern
  fhateg <- diag(rowMeans(blah))
  ghateg <- n^(-1)*t(Xplus) %*% fhateg %*% Xplus
  eg.proc.results <- list(const.bw,heg,ghateg)
  return(eg.proc.results)
}



# Test:  Null of joint homogeneity in treatment effect with respect to control variables


xmat <- cbind(rep(1,n), x1, x2, x3, x4, x5, x6, x7, x8, x91, x92, x93, x94, x95, x10, x11, x1x2, x1x3, x1x4, x1x5, x1x6, x1x7, x1x8, x1x91, x1x92, x1x93, x1x94, x1x95, x1x10, x1x11, x1x2x7, x1x2x8, x2x3, x2x4, x2x5, x1x2x5)
#               1       2   3   4   5   6   7   8   9   10   11   12   13   14   15   16   17    18    19    20    21    22    23    24     25     26     27     28     29     30     31      32      33    34    35    36         
d <- dim(xmat)[2]

# null:  no heterogeneity in treatment effects with respect to control variables
RF20 <- rbind(c(rep(0,16),1,rep(0,19)), c(rep(0,17),1,rep(0,18)), c(rep(0,18),1,rep(0,17)), c(rep(0,19),1,rep(0,16)), c(rep(0,20),1,rep(0,15)), c(rep(0,21), 1, rep(0,14)), c(rep(0,22), 1, rep(0, 13)), c(rep(0,23), 1, rep(0,12)), c(rep(0,24), 1, rep(0,11)), c(rep(0,25), 1, rep(0,10)), c(rep(0,26), 1, rep(0,9)), c(rep(0,27), 1, rep(0,8)), c(rep(0,28), 1, rep(0,7)), c(rep(0,29), 1, rep(0,6)), c(rep(0,30),1,rep(0,5)), c(rep(0,31),1,rep(0,4)), c(rep(0,32),1,rep(0,3)),c(rep(0,33),1,rep(0,2)),c(rep(0,34),1,0),c(rep(0,35),1))
df <- dim(RF20)[1]


xmat.minus <- cbind(x1, x2, x3, x4, x5, x6, x7, x8, x91, x92, x93, x94, x95, x10, x11, x1x2, x1x3, x1x4, x1x5, x1x6, x1x7, x1x8, x1x91, x1x92, x1x93, x1x94, x1x95, x1x10, x1x11, x1x2x7, x1x2x8, x2x3, x2x4, x2x5, x1x2x5)
xmat.minus.R <- cbind(x1, x2, x3, x4, x5, x6, x7, x8, x91, x92, x93, x94, x95, x10, x11)


jn <- n^(-1)*crossprod(xmat,xmat)

bhat.grid <- NULL
se.weg.grid <- NULL
se.wiid.grid <- NULL
se.wnid.grid <- NULL
se.wker.grid <- NULL
se.bxy.grid <- NULL
se.bpwy.grid <- NULL
se.bmcmb.grid <- NULL
se.bwxy.grid <- NULL
se.bwild.grid <- NULL

for (g in 1:length(alphagrid)){
  cat(paste(" Quantile", g, "of", length(alphagrid), "...\n"))
  bhat.all <- rq(y~x1+x2+x3+x4+x5+x6+x7+x8+x91+x92+x93+x94+x95+x10+x11+x1x2+x1x3+x1x4+x1x5+x1x6+x1x7+x1x8+x1x91+x1x92+x1x93+x1x94+x1x95+x1x10+x1x11+x1x2x7+x1x2x8+x2x3+x2x4+x2x5+x1x2x5, tau=alphagrid[g])
  bhat <- bhat.all$coefficients
  bhat.grid <- cbind(bhat.grid,bhat)
  
  bhat.all.R <- rq(y~x1+x2+x3+x4+x5+x6+x7+x8+x91+x92+x93+x94+x95+x10+x11, tau=alphagrid[g])
  bhat.R <- bhat.all.R$coefficients


  # Weg (i.e., the proposed procedure)

  km <- 5
  hn.list <- eg.proc(RF20,xmat.minus,y,alphagrid[g],aa1,aa2,m.fixed=FALSE, m, km)
  hn <-matrix(unlist(hn.list[3]),ncol=d,byrow=TRUE)
  vhat <- alphagrid[g]*(1-alphagrid[g])*ginv(hn) %*% jn %*% ginv(hn)
  se.weg <- sqrt(diag(vhat/n))
  se.weg.grid <- cbind(se.weg.grid,se.weg)
  F20.weg <- n*t(RF20 %*% bhat) %*% ginv(RF20 %*% vhat %*% t(RF20)) %*% (RF20 %*% bhat)

  save(F20.weg, file=paste("qdf.ee.F20.weg_",toString(g),"_k5.txt",sep=""))

  #Wiid

  bhat.info <- summary.rq(bhat.all,se="iid", hs=TRUE, covariance=TRUE) 
  vbhat.wiid <- bhat.info$cov
  se.wiid <- sqrt(diag(vbhat.wiid))
  se.wiid.grid <- cbind(se.wiid.grid,se.wiid)
  F20.wiid <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.wiid %*% t(RF20)) %*% (RF20 %*% bhat)

  save(F20.wiid, file=paste("qdf.ee.F20.wiid_",toString(g),".txt",sep=""))

  #Wnid

  bhat.info <- summary.rq(bhat.all,se="nid", hs=TRUE, covariance=TRUE) 
  vbhat.wnid <- bhat.info$cov
  se.wnid <- sqrt(diag(vbhat.wnid))
  se.wnid.grid <- cbind(se.wnid.grid,se.wnid)
  F20.wnid <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.wnid %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.wnid, file=paste("qdf.ee.F20.wnid_",toString(g),".txt",sep=""))


  #Wker

  bhat.info <- summary.rq(bhat.all,se="ker", hs=TRUE, covariance=TRUE) 
  vbhat.wker <- bhat.info$cov
  se.wker <- sqrt(diag(vbhat.wker))
  se.wker.grid <- cbind(se.wker.grid,se.wker)
  F20.wker <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.wker %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.wker, file=paste("qdf.ee.F20.wker_",toString(g),".txt",sep=""))


  #Riid

  anova.riid <- anova(bhat.all.R,bhat.all,test="rank")
  F20.riid.anova <- df*anova.riid[[1]][3]
  save(F20.riid.anova, file=paste("qdf.ee.F20.riid.anova_",toString(g),".txt",sep=""))


  #Bxy

  bhat.info <- summary.rq(bhat.all,se="boot", bsmethod="xy", covariance=TRUE)  
  vbhat.bxy <- bhat.info$cov
  se.bxy <- sqrt(diag(vbhat.bxy))
  se.bxy.grid <- cbind(se.bxy.grid,se.bxy)
  F20.bxy <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.bxy %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.bxy, file=paste("qdf.ee.F20.bxy_",toString(g),".txt",sep=""))

  #Bpwy

  bhat.info <- summary.rq(bhat.all,se="boot", bsmethod="pwy", covariance=TRUE)  
  vbhat.bpwy <- bhat.info$cov
  se.bpwy <- sqrt(diag(vbhat.bpwy))
  se.bpwy.grid <- cbind(se.bpwy.grid,se.bpwy)
  F20.bpwy <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.bpwy %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.bpwy, file=paste("qdf.ee.F20.bpwy_",toString(g),".txt",sep=""))

  #Bwxy

  bhat.info <- summary.rq(bhat.all,se="boot", bsmethod="wxy", covariance=TRUE)  
  vbhat.bwxy <- bhat.info$cov
  se.bwxy <- sqrt(diag(vbhat.bwxy))
  se.bwxy.grid <- cbind(se.bwxy.grid,se.bwxy)
  F20.bwxy <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.bwxy %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.bwxy, file=paste("qdf.ee.F20.bwxy_",toString(g),".txt",sep=""))

  #Bwild

  bhat.info <- summary.rq(bhat.all,se="boot", bsmethod="wild", covariance=TRUE)  
  vbhat.bwild <- bhat.info$cov
  se.bwild <- sqrt(diag(vbhat.bwild))
  se.bwild.grid <- cbind(se.bwild.grid,se.bwild)
  F20.bwild <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.bwild %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.bwild, file=paste("qdf.ee.F20.bwild_",toString(g),".txt",sep=""))

  #Bmcmb (WARNING:  this method is occasionally unstable)


  possibleError <- tryCatch({bhat.info <- summary.rq(bhat.all,se="boot", bsmethod="mcmb", covariance=TRUE)  
  }, error=function(e) e)
  if (!inherits(possibleError, "error")){
    vbhat.bmcmb <- bhat.info$cov
  se.bmcmb <- sqrt(diag(vbhat.bmcmb))
  se.bmcmb.grid <- cbind(se.bmcmb.grid,se.bmcmb)
  F20.bmcmb <- t(RF20 %*% bhat) %*% ginv(RF20 %*% vbhat.bmcmb %*% t(RF20)) %*% (RF20 %*% bhat)
  save(F20.bmcmb, file=paste("qdf.ee.F20.bmcmb_",toString(g),".txt",sep=""))
  }
}

F20.weg.grid <- numeric(length(alphagrid))
F20.weg.fixed.grid <- numeric(length(alphagrid))
F20.wiid.grid <- numeric(length(alphagrid))
F20.wnid.grid <- numeric(length(alphagrid))
F20.wker.grid <- numeric(length(alphagrid))
F20.riid.anova.grid <- numeric(length(alphagrid))
F20.bxy.grid <- numeric(length(alphagrid))
F20.bpwy.grid <- numeric(length(alphagrid))
F20.bmcmb.grid <- numeric(length(alphagrid))
F20.bwxy.grid <- numeric(length(alphagrid))
F20.bwild.grid <- numeric(length(alphagrid))


for (g in 1:length(alphagrid)) {


  load(file=paste("qdf.ee.F20.weg_",toString(g),"_k5.txt",sep=""))
  F20.weg.grid[g] <- F20.weg
  load(file=paste("qdf.ee.F20.wiid_",toString(g),".txt",sep=""))
  F20.wiid.grid[g] <- F20.wiid
  blah <- try(load(file=paste("qdf.ee.F20.wnid_",toString(g),".txt",sep="")))
  if ("try-error" %in% class(blah)){
    F20.wnid.grid[g] <- NA
  } else {
    F20.wnid.grid[g] <- F20.wnid
  }
  load(file=paste("qdf.ee.F20.wker_",toString(g),".txt",sep=""))
  F20.wker.grid[g] <- F20.wker
  load(file=paste("qdf.ee.F20.riid.anova_",toString(g),".txt",sep=""))
  F20.riid.anova.grid[g] <- as.numeric(F20.riid.anova[[1]])
  load(file=paste("qdf.ee.F20.bxy_",toString(g),".txt",sep=""))
  F20.bxy.grid[g] <- F20.bxy
  load(file=paste("qdf.ee.F20.bpwy_",toString(g),".txt",sep=""))
  F20.bpwy.grid[g] <- F20.bpwy
  blah <- try(load(file=paste("qdf.ee.F20.bmcmb_",toString(g),".txt",sep="")))
  if ("try-error" %in% class(blah)){
    F20.bmcmb.grid[g] <- NA
  } else {
    F20.bmcmb.grid[g] <- F20.bmcmb
  }
  load(file=paste("qdf.ee.F20.bwxy_",toString(g),".txt",sep=""))
  F20.bwxy.grid[g] <- F20.bwxy
  load(file=paste("qdf.ee.F20.bwild_",toString(g),".txt",sep=""))
  F20.bwild.grid[g] <- F20.bwild
  
}

# Compute grid of p-values for each test
pval.F20.weg.grid <- 1-pchisq(F20.weg.grid,df)
pval.F20.wiid.grid <- 1-pchisq(F20.wiid.grid,df)
pval.F20.wnid.grid <- 1-pchisq(F20.wnid.grid,df)
pval.F20.wker.grid <- 1-pchisq(F20.wker.grid,df)
pval.F20.riid.anova.grid <- 1-pchisq(F20.riid.anova.grid,df)
pval.F20.bxy.grid <- 1-pchisq(F20.bxy.grid,df)
pval.F20.bpwy.grid <- 1-pchisq(F20.bpwy.grid,df)
pval.F20.bmcmb.grid <- 1-pchisq(F20.bmcmb.grid,df)
pval.F20.bwxy.grid <- 1-pchisq(F20.bwxy.grid,df)
pval.F20.bwild.grid <- 1-pchisq(F20.bwild.grid,df)

# Reproduce Figure 2 of the main text:
par(mar=c(.26,.5,.25,.5)) # bottom, left, top, right margins
par(mfrow=c(6,2), mai=c(.26,.25,.25,.10))

plot(alphagrid,pval.F20.weg.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test", main=TeX("weg, $k_m=5$, data-driven bandwidth"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)


plot(alphagrid,pval.F20.wiid.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("wiid"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.wnid.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("wnid"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.wker.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("wker"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.riid.anova.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("riid"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.bxy.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("bxy"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.bpwy.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("bpwy"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

blah <- c(rep(1,length(pval.F20.bmcmb.grid[pval.F20.bmcmb.grid== -5])))
plot(alphagrid[pval.F20.bmcmb.grid==-5],blah,xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("bmcmb"), xlim=c(.15,.85),ylim=c(0,1))
lines(alphagrid[pval.F20.bmcmb.grid != -5],pval.F20.bmcmb.grid[pval.F20.bmcmb.grid != -5],lty=1)
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.bwxy.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("bwxy"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

plot(alphagrid,pval.F20.bwild.grid,type="l",xlab=TeX("$\\alpha$"),ylab="p-value of F-test",main=TeX("bwild"), xlim=c(.15,.85),ylim=c(0,1))
abline(h=.10, lty=3)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

# Display for each test the quantiles for which the hypothesis of covariate homogeneity in the corresponding 
# quantile treatment effect is rejected at the .10-level


alphagrid[which(pval.F20.weg.grid<.10)]
length(alphagrid[which(pval.F20.weg.grid<.10)])

alphagrid[which(pval.F20.wiid.grid<.10)]
length(alphagrid[which(pval.F20.wiid.grid<.10)])

alphagrid[which(pval.F20.wnid.grid<.10)]
length(alphagrid[which(pval.F20.wnid.grid<.10)])

alphagrid[which(pval.F20.wker.grid<.10)]
length(alphagrid[which(pval.F20.wker.grid<.10)])

alphagrid[which(pval.F20.riid.anova.grid<.10)]
length(alphagrid[which(pval.F20.riid.anova.grid<.10)])

alphagrid[which(pval.F20.bxy.grid<.10)]
length(alphagrid[which(pval.F20.bxy.grid<.10)])

alphagrid[which(pval.F20.bpwy.grid<.10)]
length(alphagrid[which(pval.F20.bpwy.grid<.10)])

alphagrid[which(pval.F20.bmcmb.grid<.10)]
length(alphagrid[which(pval.F20.bmcmb.grid<.10)])

alphagrid[which(pval.F20.bwxy.grid<.10)]
length(alphagrid[which(pval.F20.bwxy.grid<.10)])

alphagrid[which(pval.F20.bwild.grid<.10)]
length(alphagrid[which(pval.F20.bwild.grid<.10)])


# This part of the code enables reproduction of the results presented in Appendix F (Supplement p. 53)

bhat.grid <- NULL
se.grid.weg <- NULL
se.grid.wiid <- NULL
se.grid.wnid <- NULL
se.grid.wker <- NULL
se.grid.riid <- NULL
se.grid.bxy <- NULL
se.grid.bpwy <- NULL
se.grid.bmcmb <- NULL
se.grid.bwxy <- NULL
se.grid.bwild <- NULL
for (g in 1:length(alphagrid)){
  cat(paste(" Quantile", g, "of", length(alphagrid), "...\n"))
  bhat.all <- rq(y~x1+x2+x3+x4+x5+x6+x7+x8+x91+x92+x93+x94+x95+x10+x11+x1x2+x1x3+x1x4+x1x5+x1x6+x1x7+x1x8+x1x91+x1x92+x1x93+x1x94+x1x95+x1x10+x1x11+x1x2x7+x1x2x8+x2x3+x2x4+x2x5+x1x2x5, tau=alphagrid[g])
  bhat <- bhat.all$coefficients
  bhat.grid <- cbind(bhat.grid,bhat)
  
  km <- 5
  hn.list <- eg.proc(RF20,xmat.minus,y,alphagrid[g],aa1,aa2,m.fixed=FALSE, m, km)
  hn <-matrix(unlist(hn.list[3]),ncol=d,byrow=TRUE)
  vhat <- alphagrid[g]*(1-alphagrid[g])*ginv(hn) %*% jn %*% ginv(hn)
  se.weg <- sqrt(diag(n^(-1)*vhat))
  se.grid.weg <- cbind(se.grid.weg,se.weg)
  
  info <- summary.rq(bhat.all, se="iid", hs=TRUE)$coefficients # Model 1 Wiid
  se.wiid <- info[,2]
  se.grid.wiid <- cbind(se.grid.wiid, se.wiid)

  info <- summary.rq(bhat.all, se="nid", hs=TRUE)$coefficients # Model 1 Wnid
  se.wnid <- info[,2] 
  se.grid.wnid <- cbind(se.grid.wnid, se.wnid)

  info <- summary.rq(bhat.all, se="ker", hs=TRUE)$coefficients # Model 1 Wker
  se.wker <- info[,2]
  se.grid.wker <- cbind(se.grid.wker, se.wker)

  info <- summary.rq(bhat.all, se="rank", iid=TRUE, alpha=.05, tcrit=FALSE) # Model 1 Riid
  info <- info$coefficients
  se.riid <- (info[,3]-info[,2])/(2*1.96)
  se.grid.riid <- cbind(se.grid.riid, se.riid)  

  info <- summary.rq(bhat.all, se="boot", bsmethod="xy")$coefficients # Model 1 Bxy
  se.bxy <- info[,2]  
  se.grid.bxy <- cbind(se.grid.bxy,se.bxy)

  info <- summary.rq(bhat.all, se="boot", bsmethod="pwy")$coefficients # Model 1 Bpwy
  se.bpwy <- info[,2]
  se.grid.bpwy <- cbind(se.grid.bpwy, se.bpwy)

  possibleError <- tryCatch({    info <- summary.rq(bhat.all, se="boot", bsmethod="mcmb")$coefficients # Model 1 Bmcmb
  }, error=function(e) e)
  if (!inherits(possibleError, "error")){
    se.bmcmb <- info[,2]
    se.grid.bmcmb <- cbind(se.grid.bmcmb, se.bmcmb)
  }

  info <- summary.rq(bhat.all, se="boot", bsmethod="wxy")$coefficients # Model 1 Bwxy
  se.bwxy <- info[,2] 
  se.grid.bwxy <- cbind(se.grid.bwxy, se.bwxy)

  info <- summary.rq(bhat.all, se="boot", bsmethod="wild")$coefficients # Model 1 Bwild
  se.bwild <- info[,2]
  se.grid.bwild <- cbind(se.grid.bwild, se.bwild)

}

# Prudence suggests saving grid of coefficient estimates and corresponding standard errors: 
save(bhat.grid, file="qdf.ee.F20.bhat.grid.txt")
save(se.grid.weg, file="qdf.ee.F20.se.grid.weg.txt")
save(se.grid.wiid, file="qdf.ee.F20.se.grid.wiid.txt")
save(se.grid.wnid, file="qdf.ee.F20.se.grid.wnid.txt")
save(se.grid.wker, file="qdf.ee.F20.se.grid.wker.txt")
save(se.grid.riid, file="qdf.ee.F20.se.grid.riid.txt")
save(se.grid.bxy, file="qdf.ee.F20.se.grid.bxy.txt")
save(se.grid.bpwy, file="qdf.ee.F20.se.grid.bpwy.txt")
save(se.grid.bmcmb, file="qdf.ee.F20.se.grid.bmcmb.txt")
save(se.grid.bwxy, file="qdf.ee.F20.se.grid.bwxy.txt")
save(se.grid.bwild, file="qdf.ee.F20.se.grid.bwild.txt")

####
#load(file=paste("qdf.ee.F20.bhat.grid.txt"))
#load(file=paste("qdf.ee.F20.se.grid.weg.txt"))
#load(file=paste("qdf.ee.F20.se.grid.wiid.txt"))
#load(file=paste("qdf.ee.F20.se.grid.wnid.txt"))
#load(file=paste("qdf.ee.F20.se.grid.wker.txt"))
#load(file=paste("qdf.ee.F20.se.grid.riid.txt"))
#load(file=paste("qdf.ee.F20.se.grid.bxy.txt"))
#load(file=paste("qdf.ee.F20.se.grid.bpwy.txt"))
#load(file=paste("qdf.ee.F20.se.grid.bmcmb.txt"))
#load(file=paste("qdf.ee.F20.se.grid.bwxy.txt"))
#load(file=paste("qdf.ee.F20.se.grid.bwild.txt"))
####

tstat.grid.weg <- bhat.grid/se.grid.weg
tstat.grid.wiid <- bhat.grid/se.grid.wiid
tstat.grid.wnid <- bhat.grid/se.grid.wnid
tstat.grid.wker <- bhat.grid/se.grid.wker
tstat.grid.riid <- bhat.grid/se.grid.riid
tstat.grid.bxy <- bhat.grid/se.grid.bxy
tstat.grid.bpwy <- bhat.grid/se.grid.bpwy
tstat.grid.bwxy <- bhat.grid/se.grid.bwxy
tstat.grid.bwild <- bhat.grid/se.grid.bwild

idx <- seq(1,300,length.out=300)

#  Check significance of individual interaction terms based on proposed method
alphagrid.weg.check <- alphagrid[which(pval.F20.weg.grid<.10)]
alphagrid.idx.weg.check <- idx[which(pval.F20.weg.grid<.10)]
length(alphagrid.weg.check)


#xmat <- cbind(rep(1,n), x1, x2, x3, x4, x5, x6, x7, x8, x91, x92, x93, x94, x95, x10, x11, x1x2, x1x3, x1x4, x1x5, x1x6, x1x7, x1x8, x1x91, x1x92, x1x93, x1x94, x1x95, x1x10, x1x11, x1x2x7, x1x2x8, x2x3, x2x4, x2x5, x1x2x5)
#              1         2   3   4   5   6   7   8   9   10   11   12   13   14   15   16   17    18    19    20    21    22    23    24     25     26     27     28     29     30     31      32      33    34    35    36         

tstat.grid.weg.check <- tstat.grid.weg[17,alphagrid.idx.weg.check] # treatment times female
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[18,alphagrid.idx.weg.check] # treatment times black
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[19,alphagrid.idx.weg.check] # treatment times Hispanic
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[20,alphagrid.idx.weg.check] # treatment times no. of dependents
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[21,] # treatment times indicator for whether claimant expects to be recalled
alphagrid.weg.check.sig <- alphagrid[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[22,] # treatment times young
alphagrid.weg.check.sig <- alphagrid[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[23,alphagrid.idx.weg.check] # treatment times old
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[24,alphagrid.idx.weg.check] # treatment times quarter 1 indicator
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[25,alphagrid.idx.weg.check] # treatment times quarter 2 indicator
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[26,alphagrid.idx.weg.check] # treatment times quarter 3 indicator
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[27,alphagrid.idx.weg.check] # treatment times quarter 4 indicator
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[28,alphagrid.idx.weg.check] # treatment times quarter 5 indicator
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[29,alphagrid.idx.weg.check] # treatment times employment in durable goods sector
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[30,alphagrid.idx.weg.check] # treatment times LUSD district
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[31,alphagrid.idx.weg.check] # treatment times female times young
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[32,alphagrid.idx.weg.check] # treatment times female times old
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[33,alphagrid.idx.weg.check] # female times black
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[34,alphagrid.idx.weg.check] # female times Hispanic
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[35,] # female times number of dependents
alphagrid.weg.check.sig <- alphagrid[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

tstat.grid.weg.check <- tstat.grid.weg[36,alphagrid.idx.weg.check] # treatment times female times number of dependents
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)



#  Check significance of treatment * recall interaction
alphagrid.weg.check <- alphagrid[which(pval.F20.weg.grid<.10)]
alphagrid.idx.weg.check <- idx[which(pval.F20.weg.grid<.10)]
tstat.grid.weg.check <- tstat.grid.weg[21,alphagrid.idx.weg.check]
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

alphagrid.wiid.check <- alphagrid[which(pval.F20.wiid.grid<.10)]
alphagrid.idx.wiid.check <- idx[which(pval.F20.wiid.grid<.10)]
tstat.grid.wiid.check <- tstat.grid.wiid[21,alphagrid.idx.wiid.check]
alphagrid.wiid.check.sig <- alphagrid.wiid.check[which(abs(tstat.grid.wiid.check)>1.645)]
length(alphagrid.wiid.check.sig)

alphagrid.wnid.check <- alphagrid[which(pval.F20.wnid.grid<.10)]
alphagrid.idx.wnid.check <- idx[which(pval.F20.wnid.grid<.10)]
tstat.grid.wnid.check <- tstat.grid.wnid[21,alphagrid.idx.wnid.check]
alphagrid.wnid.check.sig <- alphagrid.wnid.check[which(abs(tstat.grid.wnid.check)>1.645)]
length(alphagrid.wnid.check.sig)

alphagrid.wker.check <- alphagrid[which(pval.F20.wker.grid<.10)]
alphagrid.idx.wker.check <- idx[which(pval.F20.wker.grid<.10)]
tstat.grid.wker.check <- tstat.grid.wker[21,alphagrid.idx.wker.check]
alphagrid.wker.check.sig <- alphagrid.wker.check[which(abs(tstat.grid.wker.check)>1.645)]
length(alphagrid.wker.check.sig)

alphagrid.riid.check <- alphagrid[which(pval.F20.riid.anova.grid<.10)]
alphagrid.idx.riid.check <- idx[which(pval.F20.riid.anova.grid<.10)]
tstat.grid.riid.check <- tstat.grid.riid[21,alphagrid.idx.riid.check]
alphagrid.riid.check.sig <- alphagrid.riid.check[which(abs(tstat.grid.riid.check)>1.645)]
length(alphagrid.riid.check.sig)

alphagrid.bxy.check <- alphagrid[which(pval.F20.bxy.grid<.10)]
alphagrid.idx.bxy.check <- idx[which(pval.F20.bxy.grid<.10)]
tstat.grid.bxy.check <- tstat.grid.bxy[21,alphagrid.idx.bxy.check]
alphagrid.bxy.check.sig <- alphagrid.bxy.check[which(abs(tstat.grid.bxy.check)>1.645)]
length(alphagrid.bxy.check.sig)

alphagrid.bpwy.check <- alphagrid[which(pval.F20.bpwy.grid<.10)]
alphagrid.idx.bpwy.check <- idx[which(pval.F20.bpwy.grid<.10)]
tstat.grid.bpwy.check <- tstat.grid.bpwy[21,alphagrid.idx.bpwy.check]
alphagrid.bpwy.check.sig <- alphagrid.bpwy.check[which(abs(tstat.grid.bpwy.check)>1.645)]
length(alphagrid.bpwy.check.sig)

alphagrid.bwxy.check <- alphagrid[which(pval.F20.bwxy.grid<.10)]
alphagrid.idx.bwxy.check <- idx[which(pval.F20.bwxy.grid<.10)]
tstat.grid.bwxy.check <- tstat.grid.bwxy[21,alphagrid.idx.bwxy.check]
alphagrid.bwxy.check.sig <- alphagrid.bwxy.check[which(abs(tstat.grid.bwxy.check)>1.645)]
length(alphagrid.bwxy.check.sig)

alphagrid.bwild.check <- alphagrid[which(pval.F20.bwild.grid<.10)]
alphagrid.idx.bwild.check <- idx[which(pval.F20.bwild.grid<.10)]
tstat.grid.bwild.check <- tstat.grid.bwild[21,alphagrid.idx.bwild.check]
alphagrid.bwild.check.sig <- alphagrid.bwild.check[which(abs(tstat.grid.bwild.check)>1.645)]
length(alphagrid.bwild.check.sig)

# Check significance of treatment * female * young interaction
alphagrid.weg.check <- alphagrid[which(pval.F20.weg.grid<.10)]
alphagrid.idx.weg.check <- idx[which(pval.F20.weg.grid<.10)]
tstat.grid.weg.check <- tstat.grid.weg[31,alphagrid.idx.weg.check]
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

alphagrid.wiid.check <- alphagrid[which(pval.F20.wiid.grid<.10)]
alphagrid.idx.wiid.check <- idx[which(pval.F20.wiid.grid<.10)]
tstat.grid.wiid.check <- tstat.grid.wiid[31,alphagrid.idx.wiid.check]
alphagrid.wiid.check.sig <- alphagrid.wiid.check[which(abs(tstat.grid.wiid.check)>1.645)]
length(alphagrid.wiid.check.sig)

alphagrid.wnid.check <- alphagrid[which(pval.F20.wnid.grid<.10)]
alphagrid.idx.wnid.check <- idx[which(pval.F20.wnid.grid<.10)]
tstat.grid.wnid.check <- tstat.grid.wnid[31,alphagrid.idx.wnid.check]
alphagrid.wnid.check.sig <- alphagrid.wnid.check[which(abs(tstat.grid.wnid.check)>1.645)]
length(alphagrid.wnid.check.sig)

alphagrid.wker.check <- alphagrid[which(pval.F20.wker.grid<.10)]
alphagrid.idx.wker.check <- idx[which(pval.F20.wker.grid<.10)]
tstat.grid.wker.check <- tstat.grid.wker[31,alphagrid.idx.wker.check]
alphagrid.wker.check.sig <- alphagrid.wker.check[which(abs(tstat.grid.wker.check)>1.645)]
length(alphagrid.wker.check.sig)

alphagrid.riid.check <- alphagrid[which(pval.F20.riid.anova.grid<.10)]
alphagrid.idx.riid.check <- idx[which(pval.F20.riid.anova.grid<.10)]
tstat.grid.riid.check <- tstat.grid.riid[31,alphagrid.idx.riid.check]
alphagrid.riid.check.sig <- alphagrid.riid.check[which(abs(tstat.grid.riid.check)>1.645)]
length(alphagrid.riid.check.sig)

alphagrid.bxy.check <- alphagrid[which(pval.F20.bxy.grid<.10)]
alphagrid.idx.bxy.check <- idx[which(pval.F20.bxy.grid<.10)]
tstat.grid.bxy.check <- tstat.grid.bxy[31,alphagrid.idx.bxy.check]
alphagrid.bxy.check.sig <- alphagrid.bxy.check[which(abs(tstat.grid.bxy.check)>1.645)]
length(alphagrid.bxy.check.sig)

alphagrid.bpwy.check <- alphagrid[which(pval.F20.bpwy.grid<.10)]
alphagrid.idx.bpwy.check <- idx[which(pval.F20.bpwy.grid<.10)]
tstat.grid.bpwy.check <- tstat.grid.bpwy[31,alphagrid.idx.bpwy.check]
alphagrid.bpwy.check.sig <- alphagrid.bpwy.check[which(abs(tstat.grid.bpwy.check)>1.645)]
length(alphagrid.bpwy.check.sig)

alphagrid.bwxy.check <- alphagrid[which(pval.F20.bwxy.grid<.10)]
alphagrid.idx.bwxy.check <- idx[which(pval.F20.bwxy.grid<.10)]
tstat.grid.bwxy.check <- tstat.grid.bwxy[31,alphagrid.idx.bwxy.check]
alphagrid.bwxy.check.sig <- alphagrid.bwxy.check[which(abs(tstat.grid.bwxy.check)>1.645)]
length(alphagrid.bwxy.check.sig)

alphagrid.bwild.check <- alphagrid[which(pval.F20.bwild.grid<.10)]
alphagrid.idx.bwild.check <- idx[which(pval.F20.bwild.grid<.10)]
tstat.grid.bwild.check <- tstat.grid.bwild[31,alphagrid.idx.bwild.check]
alphagrid.bwild.check.sig <- alphagrid.bwild.check[which(abs(tstat.grid.bwild.check)>1.645)]
length(alphagrid.bwild.check.sig)

# Check significance of treatment * female * old interaction
alphagrid.weg.check <- alphagrid[which(pval.F20.weg.grid<.10)]
alphagrid.idx.weg.check <- idx[which(pval.F20.weg.grid<.10)]
tstat.grid.weg.check <- tstat.grid.weg[32,alphagrid.idx.weg.check]
alphagrid.weg.check.sig <- alphagrid.weg.check[which(abs(tstat.grid.weg.check)>1.645)]
length(alphagrid.weg.check.sig)

alphagrid.wiid.check <- alphagrid[which(pval.F20.wiid.grid<.10)]
alphagrid.idx.wiid.check <- idx[which(pval.F20.wiid.grid<.10)]
tstat.grid.wiid.check <- tstat.grid.wiid[32,alphagrid.idx.wiid.check]
alphagrid.wiid.check.sig <- alphagrid.wiid.check[which(abs(tstat.grid.wiid.check)>1.645)]
length(alphagrid.wiid.check.sig)

alphagrid.wnid.check <- alphagrid[which(pval.F20.wnid.grid<.10)]
alphagrid.idx.wnid.check <- idx[which(pval.F20.wnid.grid<.10)]
tstat.grid.wnid.check <- tstat.grid.wnid[32,alphagrid.idx.wnid.check]
alphagrid.wnid.check.sig <- alphagrid.wnid.check[which(abs(tstat.grid.wnid.check)>1.645)]
length(alphagrid.wnid.check.sig)

alphagrid.wker.check <- alphagrid[which(pval.F20.wker.grid<.10)]
alphagrid.idx.wker.check <- idx[which(pval.F20.wker.grid<.10)]
tstat.grid.wker.check <- tstat.grid.wker[32,alphagrid.idx.wker.check]
alphagrid.wker.check.sig <- alphagrid.wker.check[which(abs(tstat.grid.wker.check)>1.645)]
length(alphagrid.wker.check.sig)

alphagrid.riid.check <- alphagrid[which(pval.F20.riid.anova.grid<.10)]
alphagrid.idx.riid.check <- idx[which(pval.F20.riid.anova.grid<.10)]
tstat.grid.riid.check <- tstat.grid.riid[32,alphagrid.idx.riid.check]
alphagrid.riid.check.sig <- alphagrid.riid.check[which(abs(tstat.grid.riid.check)>1.645)]
length(alphagrid.riid.check.sig)

alphagrid.bxy.check <- alphagrid[which(pval.F20.bxy.grid<.10)]
alphagrid.idx.bxy.check <- idx[which(pval.F20.bxy.grid<.10)]
tstat.grid.bxy.check <- tstat.grid.bxy[32,alphagrid.idx.bxy.check]
alphagrid.bxy.check.sig <- alphagrid.bxy.check[which(abs(tstat.grid.bxy.check)>1.645)]
length(alphagrid.bxy.check.sig)

alphagrid.bpwy.check <- alphagrid[which(pval.F20.bpwy.grid<.10)]
alphagrid.idx.bpwy.check <- idx[which(pval.F20.bpwy.grid<.10)]
tstat.grid.bpwy.check <- tstat.grid.bpwy[32,alphagrid.idx.bpwy.check]
alphagrid.bpwy.check.sig <- alphagrid.bpwy.check[which(abs(tstat.grid.bpwy.check)>1.645)]
length(alphagrid.bpwy.check.sig)

alphagrid.bwxy.check <- alphagrid[which(pval.F20.bwxy.grid<.10)]
alphagrid.idx.bwxy.check <- idx[which(pval.F20.bwxy.grid<.10)]
tstat.grid.bwxy.check <- tstat.grid.bwxy[32,alphagrid.idx.bwxy.check]
alphagrid.bwxy.check.sig <- alphagrid.bwxy.check[which(abs(tstat.grid.bwxy.check)>1.645)]
length(alphagrid.bwxy.check.sig)

alphagrid.bwild.check <- alphagrid[which(pval.F20.bwild.grid<.10)]
alphagrid.idx.bwild.check <- idx[which(pval.F20.bwild.grid<.10)]
tstat.grid.bwild.check <- tstat.grid.bwild[32,alphagrid.idx.bwild.check]
alphagrid.bwild.check.sig <- alphagrid.bwild.check[which(abs(tstat.grid.bwild.check)>1.645)]
length(alphagrid.bwild.check.sig)


for (g in 1:length(alphagrid)){
  cat(paste(" Quantile", g, "of", length(alphagrid), "...\n"))
  
  bhat <- bhat.grid[,g]
  se <- se.grid.weg[,g]
  bhat.16 <- bhat[21]
  bhat.16.ul <- bhat.16+1.645*se[21]
  bhat.16.ll <- bhat.16-1.645*se[21]
  save(bhat.16, file=paste("bhat.ee.16",toString(g),sep=""))
  save(bhat.16.ul, file=paste("bhat.ul.ee.16.weg_",toString(g),"_k5.txt",sep=""))
  save(bhat.16.ll, file=paste("bhat.ll.ee.16.weg_",toString(g),"_k5.txt",sep=""))

  bhat.17 <- bhat[22]
  bhat.17.ul <- bhat.17+1.645*se[22]
  bhat.17.ll <- bhat.17-1.645*se[22]
  save(bhat.17, file=paste("bhat.ee.17",toString(g),sep=""))
  save(bhat.17.ul, file=paste("bhat.ul.ee.17.weg_",toString(g),"_k5.txt",sep=""))
  save(bhat.17.ll, file=paste("bhat.ll.ee.17.weg_",toString(g),"_k5.txt",sep=""))
  
}

bhat.ee.16.grid <- numeric(length(alphagrid))
bhat.ul.ee.16.weg.grid <- numeric(length(alphagrid))
bhat.ll.ee.16.weg.grid <- numeric(length(alphagrid))

bhat.ee.17.grid <- numeric(length(alphagrid))
bhat.ul.ee.17.weg.grid <- numeric(length(alphagrid))
bhat.ll.ee.17.weg.grid <- numeric(length(alphagrid))

for (g in 1:length(alphagrid)) {
  load(file=paste("bhat.ee.16",toString(g),sep=""))
  bhat.ee.16.grid[g] <- bhat.16
  load(file=paste("bhat.ul.ee.16.weg_",toString(g),"_k5.txt",sep=""))
  bhat.ul.ee.16.weg.grid[g] <- bhat.16.ul
  load(file=paste("bhat.ll.ee.16.weg_",toString(g),"_k5.txt",sep=""))
  bhat.ll.ee.16.weg.grid[g] <- bhat.16.ll

  load(file=paste("bhat.ee.17",toString(g),sep=""))
  bhat.ee.17.grid[g] <- bhat.17
  load(file=paste("bhat.ul.ee.17.weg_",toString(g),"_k5.txt",sep=""))
  bhat.ul.ee.17.weg.grid[g] <- bhat.17.ul
  load(file=paste("bhat.ll.ee.17.weg_",toString(g),"_k5.txt",sep=""))
  bhat.ll.ee.17.weg.grid[g] <- bhat.17.ll
  
}

# Reproduce Figs. 1--2 in Appendix F (Supplement p. 56--57): 



# Figure 1 (Supplement p. 56)
plot(alphagrid,bhat.ul.ee.16.weg.grid,type="l", main=TeX(" "), xlim=c(.20,.80),ylim=c(-.5,.75), xlab=TeX("$\\alpha$"), ylab=TeX(" "))
lines(alphagrid,bhat.ll.ee.16.weg.grid,type="l")
polygon(c(alphagrid,rev(alphagrid)),c(bhat.ul.ee.16.weg.grid,rev(bhat.ll.ee.16.weg.grid)),col="gray")
lines(alphagrid,bhat.ee.16.grid,lty=2)
abline(h=0,lty=1)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)

# Figure 2 (Supplement p. 57)
plot(alphagrid,bhat.ul.ee.17.weg.grid,type="l", main=TeX(" "), xlim=c(.20,.80),ylim=c(-1.0,.75), xlab=TeX("$\\alpha$"), ylab=TeX(" "))
lines(alphagrid,bhat.ll.ee.17.weg.grid,type="l")
polygon(c(alphagrid,rev(alphagrid)),c(bhat.ul.ee.17.weg.grid,rev(bhat.ll.ee.17.weg.grid)),col="gray")
lines(alphagrid,bhat.ee.17.grid,lty=2)
abline(h=0,lty=1)
abline(v=.25, lty=3)
abline(v=.35, lty=3)
abline(v=.50, lty=3)
abline(v=.65, lty=3)
abline(v=.75, lty=3)
